/*******************
 * game_widget.hh - widget for displaying the game state
 * Copyright (C) 2000 Christoph Groth
 *
 * This file is part of xhalma.  You are allowed to modify and/or redistribute
 * it under the terms of the GNU General Public License.  You should have
 * received a copy named COPYING along with this program, if not you can find
 * it at http://www.gnu.org/copyleft/gpl.html
 ******************/

#ifndef GAME_WIDGET_HH
#define GAME_WIDGET_HH

#include <qwidget.h>
#include <qcolor.h>
#include <qpixmap.h>
#include "defs.hh"  // for moc
#include "hexarr.hh"
#include "vec.hh"
#include "game.hh"

class Game;

class Game_widget : public QWidget {
    Q_OBJECT;
public:
    // Attach `game' to the new widget.  `game' must exist for the whole
    // lifetime of the `Game_widget'.
    Game_widget(Game *game, Game::Callback _callback = 0,
		QWidget *parent = 0, const char *name = NULL);
    static const QColor plcol[3];  // player colors
    void get_user_move();
    void abort_getting();
    void do_ai_move(int depth);
public slots:
    void show_valid_moves(bool state);
signals:
    void user_has_moved();
protected:
    void resizeEvent(QResizeEvent *);
    void paintEvent(QPaintEvent *);
    void mouseReleaseEvent(QMouseEvent *me);
private:
    Game &g;
    Game::Callback callback;
    float scale;

    // Holds only true and false, Hexarr<bool> doesn't work.
    std::auto_ptr<Hexarr<char> > s;

    bool getting_user_move, show_moves;
    // The coords of the field from which the user wants to move.  from.x == -1
    // means no field.
    Veci from;

    Veci d;         // distance between columns/rows
    int diam;       // diameter
    Veci b;         // outer borders

    QPixmap pmap;
};

#endif /* GAME_WIDGET_HH */
