/*******************
 * main_wnd.hh - main window widget
 * Copyright (C) 2000 Christoph Groth
 *
 * This file is part of xhalma.  You are allowed to modify and/or redistribute
 * it under the terms of the GNU General Public License.  You should have
 * received a copy named COPYING along with this program, if not you can find
 * it at http://www.gnu.org/copyleft/gpl.html
 ******************/

#ifndef MAIN_WND_HH
#define MAIN_WND_HH

#include <vector>
#include <string>
#include <map>
#include <qwidget.h>
#include "defs.hh" // for moc
#include "game.hh"

class QPushButton;
class QComboBox;
class QLabel;
class QCheckBox;
class QProgressBar;
class Game_widget;

class Main_wnd : public QWidget
{
    Q_OBJECT;
public:
    Main_wnd(QWidget *parent = NULL, const char *name = NULL);
    ~Main_wnd();
public slots:
    void user_move_done();
    void do_restart();
    void show_about();
    void show_rules();
    static bool set_progress(const Game *game, float progress);
protected:
    void resizeEvent(QResizeEvent *);
private slots:
    void dont_cont_comp();
private:
    void set_enabled(bool enable);
    bool is_victory();
    std::auto_ptr<Game> g;
    Game_widget *gw;
    QPushButton *cont, *restart, *rules, *about, *quit;
    QComboBox *blue_combo, *red_combo;
    QLabel *blue_label, *red_label;
    QCheckBox *show_moves;
    QProgressBar *pbar;
    const int buttons_w, min_buttons_h;
    bool cont_comp;  // The value set_progress will return to Game.
    typedef std::pair<std::string, int> Ai_level;
    std::vector<Ai_level> ai_levels;
    // used by set_progress to find out which Main_wnd the call refers to.
    static std::map<const Game *, Main_wnd *> windows;
    static const char *const silly_text, *const rules_text;
    static const int pbar_stepc;
};

#endif // MAIN_WND_HH
